%Authors: 	Martin Holler and Kristian Bredies
%           	University of Graz
%Contact	martin.holler@uni-graz.at
%Usage permited only for academic purposes
%NOTE: This is NON-OPTIMIZED matlab code

%Testscript for TGV-wavelet based image zooming according to
%K. Bredies and M. Holler. A TGV regularized wavelet based zooming model. Scale Space and Variational Methods in Computer Vision, Springer LNCS, 7893:149-160, 2013.
%If you like and use this code, please cite the above reference


%Basic usage:----------------------------------------------
%tgv_z = wavelet_zoom(image_name,stopping_rule,stopping_parameter,z_exp,filter_name,alph0)

%where
%image_name             Name of the low resolution input image
%stopping_rule          String to define stopping rule, either 'iteration' or 'gap'
%stopping_parameter     Number to define stopping parameter, either number of iteratons or value of the primal-dual gap
%z_exp                  Zooming exponent, image will be zoomed by a facter 2^z_exp
%filter_name            Name of the wavelt transform, either 'LeGall' or 'CDF' or 'haar' NOTE: With the orthogonal 'haar' wavelet, use the faster "orth_wavelet_zoom.m" function with the same input
%alph0                  TGV parameter, use alpha0 = 4 to reproduce the paper results

%tgv_z                  Zoomed iamge


%Advanced usage:----------------------------------------------
%[tgv_z,tgv,gap,ID,data_error,max_data_error,sig_save,std,bil,cub,lanc2,lanc3,wave] = wavelet_zoom(image_name,stopping_rule,stopping_parameter,z_exp,filter_name,alph0)



%Example usage:----------------------------------------------

%Set parameters
stopping_rule = 'gap';
stopping_parameter = 0.1;
alph0=4;
z_exp = 2;

%Choose filter
filter_name = 'CDF';
%filter_name = 'LeGall';
%filter_name = 'haar';

%Choose image
image_name = 'barbara_rope.png';
%image_name = 'girlseye_CDFsubf4.png';


display('Testing...');%###############################################################################


if strcmp(filter_name,'haar') %Use simpler version for orthgonal wavelets
    tgv_z = orth_wavelet_zoom(image_name,stopping_rule,stopping_parameter,z_exp,filter_name,alph0);
else
    tgv_z = wavelet_zoom(image_name,stopping_rule,stopping_parameter,z_exp,filter_name,alph0);
end





%Reproduce results of 
%K. Bredies and M. Holler
%A TGV-based framework for variational image decompression, zooming and reconstruction. Part II: Numerics
%{
display('Testing different zooming images...');%###############################################################################
%Global Parameter
stopping_rule = 'gap';
stopping_parameter = 0.1;
alph0=4;


filter_name = 'CDF'; z_exp = 2; image_name = 'barbara_rope.png';
[tgv_z,tgv,gap,ID,data_error,max_data_error,sig_save,std,bil,cub,lanc2,lanc3,wave] = wavelet_zoom(image_name,stopping_rule,stopping_parameter,z_exp,filter_name,alph0);
imwrite(tgv_z,[image_name(1:end-4),'_',filter_name,'_a',num2str(alph0),'_tgv.png'],'png','Compression','none');
clearvars -except stopping_rule stopping_parameter gap_stop max_it w_norm alph0; close all;


filter_name = 'haar'; z_exp = 2; image_name = 'barbara_rope.png';
[tgv_z,tgv,gap,data_error,max_data_error,sig_save,std,bil,cub,lanc2,lanc3,wave] = orth_wavelet_zoom(image_name,stopping_rule,stopping_parameter,z_exp,filter_name,alph0);
imwrite(tgv_z,[image_name(1:end-4),'_',filter_name,'_a',num2str(alph0),'_tgv.png'],'png','Compression','none');
clearvars -except stopping_rule stopping_parameter gap_stop max_it w_norm alph0; close all;


filter_name = 'haar'; z_exp = 2; image_name = 'test.png';
[tgv_z,tgv,gap,data_error,max_data_error,sig_save,std,bil,cub,lanc2,lanc3,wave] = orth_wavelet_zoom(image_name,stopping_rule,stopping_parameter,z_exp,filter_name,alph0);
imwrite(tgv_z,[image_name(1:end-4),'_',filter_name,'_a',num2str(alph0),'_tgv.png'],'png','Compression','none');
clearvars -except stopping_rule stopping_parameter gap_stop max_it w_norm alph0; close all;
%}


